@@ -2,11 +2,14 @@ class AltinnAuthClientConfig:
     """
     Configuration class for AltinnAuthClient
     """
-    def __init__(self,
-                 maskinport_client_id: str,
-                 keycloak_secret_path: str,
-                 platform_environment: str,
-                 altinn_base_url: str):
+
+    def __init__(
+        self,
+        maskinport_client_id: str,
+        keycloak_secret_path: str,
+        platform_environment: str,
+        altinn_base_url: str,
+    ):
         """
         :param maskinport_client_id: A valid client id in Maskinporten
         :param keycloak_secret_path: The path to the keycloak secret (in GCP secret manager)
