@@ -4,6 +4,10 @@ def exception_handler(client_name: str):
             try:
                 return func(*args, **kwargs)
             except Exception as e:
-                raise Exception(f"Client '{client_name}' failed to fetch with error:\n{e}")
+                raise Exception(
+                    f"Client '{client_name}' failed to fetch with error:\n{e}"
+                )
+
         return inner_function
+
     return client_wrapper
